@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
-import sys, os, re, shutil
+import sys, os, shutil
 import zc.buildout
 import zc.recipe.egg
 import logging
@@ -191,6 +191,13 @@ class Recipe:
             if not os.path.exists(file_storage_dir):
                 os.makedirs(file_storage_dir)
 
+            if options.get('authentication-database', ''):
+                authentication = authentication_template % \
+                        dict(database=options.get('authentication-database'),
+                             realm=options.get('authentication-realm', 'ZEO'))
+            else:
+                authentication = ''
+
             pid_file = options.get(
                 'pid-file',
                 os.path.join(base_dir, 'var', self.name + '.pid'))
@@ -215,6 +222,7 @@ class Recipe:
                 socket_name = socket_name,
                 z_log = z_log,
                 z_log_filename = z_log_filename,
+                authentication = authentication,
                 storage = storage,
                 zeo_address = zeo_address,
                 pid_file = pid_file,
@@ -272,18 +280,33 @@ class Recipe:
                     extra_paths = self.ws_locations + [directory],
                     )
         else:
+            host = port = socket_path = ''
             zeo_address = options.get('zeo-address', '8100')
             parts = zeo_address.split(':')
+
             if len(parts) == 1:
-                parts[0:0] = ['127.0.0.1']
+                try:
+                    # if the only argument is a port, which must be an int,
+                    # we use 127.0.0.1 as the host by default
+                    int_port = int(zeo_address)
+                    host = '127.0.0.1'
+                    port = zeo_address
+                except ValueError:
+                    # The address is a simple string, we now assume it is
+                    # a path to a Unix socket file 
+                    socket_path = zeo_address
+            else:
+                host, port = parts
             
+            address_info = 'host = "%s"\nport = "%s"\nsocket_path = "%s"' % (
+                                host, port, socket_path)
             extra_paths = [location for location in self.ws_locations
                            if location not in self.zodb_ws.entries]
             zc.buildout.easy_install.scripts(
                 [('zeopack', 'plone.recipe.zope2zeoserver.pack', 'main')],
                 self.zodb_ws, options['executable'], options['bin-directory'],
-                initialization='host = "%s"\nport = %s' % tuple(parts),
-                arguments='host, port', extra_paths=extra_paths
+                initialization=address_info,
+                arguments='host, port, socket_path', extra_paths=extra_paths
                 )
 
         
@@ -384,8 +407,14 @@ z_log_file = """\
     </logfile>
 """.strip()
 
+authentication_template = """
+  authentication-protocol digest
+  authentication-database %(database)s
+  authentication-realm %(realm)s
+"""
+
 # The template used to build zeo.conf
-zeo_conf_template="""\
+zeo_conf_template = """\
 %%define INSTANCE %(instance_home)s
 
 <zeo>
@@ -393,6 +422,7 @@ zeo_conf_template="""\
   read-only false
   invalidation-queue-size %(invalidation_queue_size)s
   pid-filename %(pid_file)s
+  %(authentication)s
 </zeo>
 
 %(storage)s
